restore vp9 and vpx in libwebm

renaming should not have been applied to third_party.

Change-Id: I95be7ec4b7558298cd49ec4c5d1ed15a17ad222b
diff --git a/third_party/libwebm/common/hdr_util.h b/third_party/libwebm/common/hdr_util.h
index 1a3ca74..d30c2b9 100644
--- a/third_party/libwebm/common/hdr_util.h
+++ b/third_party/libwebm/common/hdr_util.h
@@ -43,8 +43,8 @@
 bool CopyColour(const mkvparser::Colour& parser_colour,
                 mkvmuxer::Colour* muxer_colour);
 
-// Returns AV1 profile upon success or 0 upon failure.
-int ParseAvxCodecPrivate(const uint8_t *private_data, int32_t length);
+// Returns VP9 profile upon success or 0 upon failure.
+int ParseVpxCodecPrivate(const uint8_t* private_data, int32_t length);
 
 }  // namespace libwebm
diff --git a/third_party/libwebm/common/hdr_util.cc b/third_party/libwebm/common/hdr_util.cc
index 0b53cd5..e1a9842 100644
--- a/third_party/libwebm/common/hdr_util.cc
+++ b/third_party/libwebm/common/hdr_util.cc
@@ -112,7 +112,7 @@
   return true;
 }
 
 // Format of AVx private data:
 //
 //   0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
 //  +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
@@ -151,18 +151,20 @@
 //   62: Level 6.2
 //
 // See the following link for more information:
-// http://www.webmproject.org/av1/profiles/
-int ParseAvxCodecPrivate(const uint8_t *private_data, int32_t length) {
-  const int kAvxCodecPrivateLength = 3;
-  if (!private_data || length != kAvxCodecPrivateLength) return 0;
+// http://www.webmproject.org/vp9/profiles/
+int ParseVpxCodecPrivate(const uint8_t* private_data, int32_t length) {
+  const int kVpxCodecPrivateLength = 3;
+  if (!private_data || length != kVpxCodecPrivateLength)
+    return 0;
 
   const uint8_t id_byte = *private_data;
   if (id_byte != 1)
     return 0;
 
-  const int kAvxProfileLength = 1;
+  const int kVpxProfileLength = 1;
   const uint8_t length_byte = private_data[1];
-  if (length_byte != kAvxProfileLength) return 0;
+  if (length_byte != kVpxProfileLength)
+    return 0;
 
   const int level = static_cast<int>(private_data[2]);
 
@@ -112,7 +112,7 @@
 }
 
-// Format of AVx private data:
+// Format of VPx private data:
 //
 //   0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1